@@ -17,6 +17,8 @@
 #include <PimCommon/KActionMenuChangeCase>
 #include <PimCommon/NeedUpdateVersionUtils>
 #include <PimCommon/NeedUpdateVersionWidget>
+#include <PimCommon/WhatsNewDialog>
+#include <PimCommon/WhatsNewMessageWidget>
 
 #include <KSharedConfig>
 #include <PimCommon/NetworkManager>
@@ -51,7 +53,7 @@
 // signal handler for SIGINT & SIGTERM
 #ifdef Q_OS_UNIX
 #include <KSignalHandler>
-#include <signal.h>
+#include <csignal>
 #include <unistd.h>
 #endif
 #include <KWindowConfig>
@@ -61,6 +63,8 @@
 #include <PimCommon/VerifyNewVersionWidget>
 #endif
 
+#include "whatsnew/whatsnewtranslations.h"
+
 namespace
 {
 static const char mySieveEditorMainWindowConfigGroupName[] = "SieveEditorMainWindow";
@@ -99,6 +103,20 @@ SieveEditorMainWindow::SieveEditorMainWindow(QWidget *parent)
         }
     }
 
+    WhatsNewTranslations translations;
+    const QString newFeaturesMD5 = translations.newFeaturesMD5();
+    if (!newFeaturesMD5.isEmpty()) {
+        const bool hasNewFeature = (SieveEditorGlobalConfig::self()->previousNewFeaturesMD5() != newFeaturesMD5);
+        if (hasNewFeature) {
+            auto whatsNewMessageWidget = new PimCommon::WhatsNewMessageWidget(this);
+            whatsNewMessageWidget->setWhatsNewInfos(translations.createWhatsNewInfo());
+            whatsNewMessageWidget->setObjectName(QStringLiteral("whatsNewMessageWidget"));
+            mainWidgetLayout->addWidget(whatsNewMessageWidget);
+            SieveEditorGlobalConfig::self()->setPreviousNewFeaturesMD5(newFeaturesMD5);
+            whatsNewMessageWidget->animatedShow();
+        }
+    }
+
     mMainWidget = new SieveEditorCentralWidget(this, actionCollection());
     mainWidgetLayout->addWidget(mMainWidget);
 #if WITH_KUSERFEEDBACK
@@ -137,6 +155,14 @@ SieveEditorMainWindow::~SieveEditorMainWindow()
     writeConfig();
 }
 
+void SieveEditorMainWindow::slotWhatsNew()
+{
+    WhatsNewTranslations translations;
+    PimCommon::WhatsNewDialog dlg(translations.createWhatsNewInfo(), this);
+    dlg.updateInformations();
+    dlg.exec();
+}
+
 void SieveEditorMainWindow::readConfig()
 {
     create(); // ensure a window is created
@@ -357,6 +383,10 @@ void SieveEditorMainWindow::setupActions()
     ac->addAction(QStringLiteral("colorscheme_menu"), KColorSchemeMenu::createMenu(manager, this));
     mShowMenuBarAction->setChecked(SieveEditorGlobalConfig::self()->showMenuBar());
     slotToggleMenubar(true);
+
+    auto showWhatsNewAction = new QAction(QIcon::fromTheme(QStringLiteral("sieveeditor")), i18n("What's new"), this);
+    ac->addAction(QStringLiteral("whatsnew"), showWhatsNewAction);
+    connect(showWhatsNewAction, &QAction::triggered, this, &SieveEditorMainWindow::slotWhatsNew);
 }
 
 void SieveEditorMainWindow::slotActivateRequested(const QStringList &arguments, const QString &workingDirectory)
